@@ -110,19 +110,12 @@ check_device() {
 
 
 initialize_chroot() {
-	gcc_pkgname="gcc"
-	if [ "$gcc6_arg" = "1" ]; then
-		gcc_pkgname="gcc6"
-	fi
-	if [ "$gcc4_arg" = "1" ]; then
-		gcc_pkgname="gcc4"
-	fi
-
 	# Kernel architecture
 	# shellcheck disable=SC2154
 	case "$deviceinfo_arch" in
 		aarch64*) arch="arm64" ;;
 		arm*) arch="arm" ;;
+		riscv*) arch="riscv" ;;
 		x86_64) arch="x86_64" ;;
 		x86) arch="x86" ;;
 	esac
@@ -136,29 +129,57 @@ initialize_chroot() {
 	if [ "$arch" = "$host_arch" ] || \
 		{ [ "$arch_substr" = "arm" ] && [ "$arch_substr" = "$arch" ]; } || \
 		{ [ "$arch" = "arm64" ] && [ "$host_arch" = "aarch64" ]; } || \
+		{ [ "$arch" = "riscv" ] && [ "$host_arch" = "riscv64" ]; } || \
 		{ [ "$arch" = "x86" ] && [ "$host_arch" = "x86_64" ]; }; then
 		need_cross_compiler=0
 	fi
 
+	# LLVM is a cross compiler in itself
+	if [ -z "$gcc_arg" ] && [ -z "$gcc6_arg" ] && [ -z "$gcc4_arg" ]; then
+		need_cross_compiler=0
+		pkgs="clang lld llvm"
+		toolchain_name="llvm"
+	else
+		if [ "$gcc6_arg" = "1" ]; then
+			gcc_pkgname="gcc6"
+		elif [ "$gcc4_arg" = "1" ]; then
+			gcc_pkgname="gcc4"
+		elif [ "$gcc_arg" = "1" ]; then
+			gcc_pkgname="gcc"
+		fi
+
+		cross_binutils=""
+		cross_gcc=""
+		if [ "$need_cross_compiler" = 1 ]; then
+			cross_binutils="binutils-$deviceinfo_arch"
+			cross_gcc="$gcc_pkgname-$deviceinfo_arch"
+		fi
+
+		pkgs="$cross_binutils $cross_gcc $gcc_pkgname g++"
+		toolchain_name="$gcc_pkgname"
+	fi
+
 	# Don't initialize twice
-	flag="$chroot/tmp/envkernel/${gcc_pkgname}_setup_done"
+	flag="$chroot/tmp/envkernel/${toolchain_name}_setup_done"
 	[ -e "$flag" ] && return
 
 	# Install needed packages
 	echo "Initializing Alpine chroot (details: 'pmbootstrap log')"
 
-	cross_binutils=""
-	cross_gcc=""
-	if [ "$need_cross_compiler" = 1 ]; then
-		cross_binutils="binutils-$deviceinfo_arch"
-		cross_gcc="$gcc_pkgname-$deviceinfo_arch"
-	fi
-
 	# FIXME: Ideally we would not "guess" the dependencies here.
 	# It might be better to take a kernel package name as parameter
 	#   (e.g. . envkernel.sh linux-postmarketos-mainline)
 	# and install its build dependencies.
 
+	# If we're running zsh, enable word splitting for this next section. pmbootstrap#2685 workaround.
+	if [ -n "${ZSH_VERSION-}" ]; then
+		case $(setopt)
+			in *shwordsplit*) has_shwordsplit=1 ;;
+		esac
+
+		setopt shwordsplit
+	fi
+
 	# shellcheck disable=SC2086,SC2154
 	"$pmbootstrap" -q chroot -- apk -q add \
 		abuild \
@@ -166,14 +187,11 @@ initialize_chroot() {
 		bc \
 		binutils \
 		bison \
-		$cross_binutils \
-		$cross_gcc \
+		clang-libclang \
 		diffutils \
 		elfutils-dev \
 		findutils \
 		flex \
-		g++ \
-		"$gcc_pkgname" \
 		gmp-dev \
 		gnutls-dev \
 		linux-headers \
@@ -185,10 +203,21 @@ initialize_chroot() {
 		ncurses-dev \
 		perl \
 		py3-dt-schema \
+		rust \
+		rust-bindgen \
+		rust-src \
+		rustfmt \
 		sed \
 		yamllint \
 		yaml-dev \
-		xz || return 1
+		xz \
+		$pkgs || return 1
+
+	# Disable shwordsplit if it wasn't enabled before, and unset the temporary variable if it was.
+	if [ -n "${ZSH_VERSION-}" ]; then
+		[ -z "$has_shwordsplit" ] && unsetopt shwordsplit
+		[ -n "$has_shwordsplit" ] && unset has_shwordsplit
+	fi
 
 	# Create /mnt/linux
 	sudo mkdir -p "$chroot/mnt/linux"
@@ -247,7 +276,11 @@ set_alias_make() {
 		cmd="$cmd CROSS_COMPILE=$cross_compiler"
 	fi
 	cmd="$cmd make -C /mnt/linux O=/mnt/linux/.output"
-	cmd="$cmd CC=$cc HOSTCC=$hostcc"
+	if [ -z "$gcc_arg" ] && [ -z "$gcc6_arg" ] && [ -z "$gcc4_arg" ]; then
+		cmd="$cmd LLVM=1"
+	else
+		cmd="$cmd CC=$cc HOSTCC=$hostcc"
+	fi
 
 	# shellcheck disable=SC2139
 	alias make="$cmd"
@@ -352,6 +385,7 @@ print_usage() {
 	echo "    --fish        Print fish alias syntax (internally used)"
 	echo "    --gcc6        Use GCC6 cross compiler"
 	echo "    --gcc4        Use GCC4 cross compiler"
+	echo "    --gcc         Use GCC cross compiler"
 	echo "    --help        Show this help message"
 }
 
@@ -360,6 +394,7 @@ parse_args() {
 	unset fish_arg
 	unset gcc6_arg
 	unset gcc4_arg
+	unset gcc_arg
 
 	while [ "${1:-}" != "" ]; do
 		case $1 in
@@ -375,6 +410,10 @@ parse_args() {
 			gcc4_arg=1
 			shift
 			;;
+		--gcc)
+			gcc_arg=1
+			shift
+			;;
 		--help)
 			shift
 			return 0
