@@ -4,7 +4,7 @@
 import sys
 import os
 import traceback
-from typing import Any, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING
 from pathlib import Path
 
 from pmb.helpers.exceptions import BuildFailedError, NonBugError
@@ -15,7 +15,6 @@ if TYPE_CHECKING:
 from . import config
 from . import parse
 from .config import init as config_init, require_programs
-from .helpers import frontend
 from .helpers import logging
 from .helpers import mount
 from .helpers import other
@@ -25,7 +24,7 @@ from .core.context import get_context
 from .commands import run_command
 
 # pmbootstrap version
-__version__ = "3.1.0"
+__version__ = "3.7.0"
 
 # Python version check
 # === CHECKLIST FOR UPGRADING THE REQUIRED PYTHON VERSION ===
@@ -114,9 +113,7 @@ def main() -> int:
 
         # Still active notice
         if mount.ismount(Chroot.native() / "dev"):
-            logging.info(
-                "NOTE: chroot is still active (use 'pmbootstrap" " shutdown' as necessary)"
-            )
+            logging.info("NOTE: chroot is still active (use 'pmbootstrap shutdown' as necessary)")
         logging.info("DONE!")
 
     except KeyboardInterrupt:
@@ -147,7 +144,7 @@ def main() -> int:
 
         print_log_hint()
         print()
-        print("Before you report this error, ensure that pmbootstrap is " "up to date.")
+        print("Before you report this error, ensure that pmbootstrap is up to date.")
         print(
             "Find the latest version here: https://gitlab.postmarketos.org/postmarketOS/pmbootstrap/-/tags"
         )
