@@ -22,7 +22,6 @@ import pmb.config.pmaports
 from pmb.meta import Cache
 import pmb.helpers.http
 import pmb.helpers.run
-import pmb.helpers.other
 
 
 def apkindex_hash(url: str, length: int = 8) -> Path:
@@ -146,8 +145,9 @@ def apkindex_files(
 
     # Resolve the APKINDEX.$HASH.tar.gz files
     ret.extend(
-        get_context().config.work / f"cache_apk_{arch}" / apkindex_hash(url)
+        file
         for url in urls(False, exclude_mirrors)
+        if (file := get_context().config.work / f"cache_apk_{arch}" / apkindex_hash(url)).exists()
     )
 
     return ret
@@ -171,7 +171,8 @@ def update(arch: Arch | None = None, force: bool = False, existing_only: bool =
         return False
 
     # Architectures and retention time
-    architectures = [arch] if arch else Arch.supported_binary()
+    supported_binary = Arch.supported_binary()
+    architectures = [arch] if arch else supported_binary
     retention_hours = pmb.config.apkindex_retention_time
     retention_seconds = retention_hours * 3600
 
@@ -223,7 +224,10 @@ def update(arch: Arch | None = None, force: bool = False, existing_only: bool =
         pmb.helpers.cli.progress_print(i / len(outdated))
         temp = pmb.helpers.http.download(url, "APKINDEX", False, logging.DEBUG, True, True)
         if not temp:
-            if os.environ.get("PMB_APK_FORCE_MISSING_REPOSITORIES") == "1":
+            if (
+                os.environ.get("PMB_APK_FORCE_MISSING_REPOSITORIES") == "1"
+                or arch not in supported_binary
+            ):
                 missing_ignored = True
                 continue
             else:
@@ -237,7 +241,7 @@ def update(arch: Arch | None = None, force: bool = False, existing_only: bool =
 
     if missing_ignored:
         logging.warn_once(
-            "NOTE: ignoring missing APKINDEX due to PMB_APK_FORCE_MISSING_REPOSITORIES=1 (fine during bootstrap)"
+            "NOTE: ignoring missing APKINDEX due to PMB_APK_FORCE_MISSING_REPOSITORIES=1 or architecture without binary repo (fine during bootstrap)"
         )
 
     return True
